@@ -1,3 +1,5 @@
+'''This module is used to gather all the Git-related data.'''
+
 import os
 import sh
 
@@ -5,6 +7,7 @@ FORMAT = '%n'.join(['%H', '%aN', '%ae', '%at', '%cN', '%ce', '%ct', '%s'])
 
 
 def gitrepo(root):
+    '''Construct a dictionary holding all the Git data that can be found.'''
     oldpwd = sh.pwd().strip()
     sh.cd(root)
     gitlog = sh.git('--no-pager', 'log', '-1',
